;; Generated package description from magit-section.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "magit-section" "4.7.0.0.20260807.2" "Sections for read-only buffers" '((emacs "28.1") (compat "31.0") (cond-let "1.1") (llama "1.0") (seq "2.24")) :commit "b1742562074e794348bdc56da838ac9d3ae40364" :authors '(("Jonas Bernoulli" . "emacs.magit@jonas.bernoulli.dev")) :maintainer '("Jonas Bernoulli" . "emacs.magit@jonas.bernoulli.dev") :keywords '("tools") :url "https://github.com/magit/magit")
